@@ -1,33 +1,25 @@
-/****************************************************************************
-**
-** Copyright (C) 2008 Urs Wolfer <uwolfer @ kde.org>
-** Copyright (C) 2009 Tony Murray <murraytony@gmail.com>
-**
-** This file is part of KDE.
-**
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; see the file COPYING. If not, write to
-** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-** Boston, MA 02110-1301, USA.
-**
-****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Urs Wolfer <uwolfer@kde.org>
+    SPDX-FileCopyrightText: 2009 Tony Murray <murraytony@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "remotedesktopsmodel.h"
 #include "krdc_debug.h"
 
 #include <KLocalizedString>
 #include<KCoreAddons/KFormat>
+#ifdef BUILD_ZEROCONF
+#include <kdnssd_version.h>
+#if KDNSSD_VERSION >= QT_VERSION_CHECK(5, 84, 0)
+#include <KDNSSD/ServiceBrowser>
+#include <KDNSSD/RemoteService>
+#else
 #include <DNSSD/ServiceBrowser>
+#include <DNSSD/RemoteService>
+#endif
+#endif
 #include <QDateTime>
 #include <QLoggingCategory>
 #include <QStandardPaths>
@@ -280,10 +272,10 @@ void RemoteDesktopsModel::buildModelFromBookmarkGroup(const KBookmarkGroup &grou
 void RemoteDesktopsModel::servicesChanged()
 {
     //redo list because it is easier than finding and removing one that disappeared
-    QList<KDNSSD::RemoteService::Ptr> services = zeroconfBrowser->services();
+    const QList<KDNSSD::RemoteService::Ptr> services = zeroconfBrowser->services();
     QUrl url;
     removeAllItemsFromSources(RemoteDesktop::Zeroconf);
-    foreach(KDNSSD::RemoteService::Ptr service, services) {
+    for (const KDNSSD::RemoteService::Ptr& service : services) {
         url.setScheme(m_protocols[service->type()].toLower());
         url.setHost(service->hostName());
         url.setPort(service->port());
